/*+-------------------------------------------------------------------------
	ecutermio.c

  Defined functions:
	ecubreak(fd)
	ecudrain(fd)
	ecuflow(fd, command)
	ecuflush(fd, flush_type)
	ecugetattr(fd, t)
	ecugetspeed(t)
	ecusetattr(fd, flag, t)
	ecusetspeed(t, speed)

  "Tell the moon; don't tell the March Hare:  He is here to look around."
  -- Yes.

--------------------------------------------------------------------------*/
/*+:EDITS:*/
/*:05-04-1994-04:39-wht@n4hgf-ECU release 3.30 */
/*:03-13-1994-18:20-wht@fep-only CFG_TermiosLineio needed */
/*:03-13-1994-18:18-wht@fep-use cfsetispeed/cfsetospeed in lieu of cfsetspeed */
/*:03-13-1994-18:18-wht@fep-first use of edit history */
/*:12-19-1994-12:00-dharris-ecudrain added */
/*:12-18-1994-12:00-dharris-transplant into 3.28.06 */
/*:12-16-1994-12:00-dharris-creation */

#include "ecu.h"

/*+-------------------------------------------------------------------------
	ecugetattr(fd, t)
--------------------------------------------------------------------------*/
int
ecugetattr(fd, t)
int fd;
struct termio *t;
{
#if defined(CFG_TermiosLineio)
	return (tcgetattr(fd, t));
#else
	return (ioctl(fd, TCGETA, t));
#endif
}							 /* end of ecugetattr */

/*+-------------------------------------------------------------------------
	ecusetattr(fd, flag, t)
--------------------------------------------------------------------------*/
int
ecusetattr(fd, flag, t)
int fd, flag;
struct termio *t;
{
#if defined(CFG_TermiosLineio)
	return (tcsetattr(fd, flag, t));
#else
	return (ioctl(fd, flag, (char *)t));
#endif
}							 /* end of ecusetattr */

/*+-------------------------------------------------------------------------
	ecuflow(fd, command)
--------------------------------------------------------------------------*/
int
ecuflow(fd, command)
int fd, command;
{
#if defined(CFG_TermiosLineio)
	return (tcflow(fd, command));
#else
	return (ioctl(fd, TCXONC, command));
#endif
}							 /* end of ecuflow */

/*+-------------------------------------------------------------------------
	ecuflush(fd, flush_type)
--------------------------------------------------------------------------*/
int
ecuflush(fd, flush_type)
int fd, flush_type;
{
#if defined(CFG_TermiosLineio)
	return (tcflush(fd, flush_type));
#else
	return (ioctl(fd, TCFLSH, flush_type));
#endif
}							 /* end of ecuflush */

/*+-------------------------------------------------------------------------
	ecubreak(fd)
--------------------------------------------------------------------------*/
int
ecubreak(fd)
int fd;
{
#if defined(CFG_TermiosLineio)
	return (tcsendbreak(fd, 250000L));
#else
	return (ioctl(fd, TCSBRK, (char *)0));
#endif
}							 /* end of ecubreak */

/*+-------------------------------------------------------------------------
	ecudrain(fd)
--------------------------------------------------------------------------*/
int
ecudrain(fd)
int fd;
{
#if defined(CFG_TermiosLineio)
	return (tcdrain(fd));
#else
	return (ioctl(fd, TCSBRK, 1));
#endif
}							 /* end of ecudrain */

/*+-------------------------------------------------------------------------
	ecugetspeed(t)
--------------------------------------------------------------------------*/
int
ecugetspeed(t)
struct termio *t;
{
#if defined(CFG_TermiosLineio)
	return (cfgetispeed(t));
#else
	return ((unsigned)t->c_cflag & CBAUD);
#endif
}							 /* end of ecugetspeed */

/*+-------------------------------------------------------------------------
	ecusetspeed(t, speed)
--------------------------------------------------------------------------*/
void
ecusetspeed(t, speed)
struct termio *t;
int speed;
{

	/*
	 * we use termios on sunos 4.1.x, but cfsetspeed() is not defined
	 * Actually, in at least Solaris 2.3, it isn't here either.... RLipe
	 * [not in Motorola SVR4.1 either; use i/o pair everywhere -- wht]
	 */
#if defined(CFG_TermiosLineio)
#if 1
	cfsetospeed(t, speed);
	cfsetispeed(t, speed);
#else
	cfsetspeed(t, speed);
#endif /* decommitted */
#else
	t->c_cflag &= ~CBAUD;
	t->c_cflag |= speed;
#endif /* CFG_TermiosLineio */
}							 /* end of ecusetspeed */

/* vi: set tabstop=4 shiftwidth=4: */
/* end of ecutermio.c */
